==> munit-remote-2.0.0-rc-sources.jar: org/mule/munit/remote/api/configuration/MavenConfiguration.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
/*
* Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
* copyright law. All use of this software is subject to MuleSoft's Master Subscription
* Agreement (or other master license agreement) separately entered into in writing between
* you and MuleSoft. If such an agreement is not in place, you may not use the software.
*/
package org.mule.munit.remote.api.configuration;

/**
 * Define the configuration required for mule-maven-client
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class MavenConfiguration {

  private String settingsXmlFilePath;
  private String globalSettingsXmlFilePath;
  private String mavenRepositoryDirectoryPath;

  private Boolean forcePolicyUpdate = Boolean.FALSE;

  protected MavenConfiguration(String settingsXmlFilePath, String globalSettingsXmlFilePath,
                               String mavenRepositoryDirectoryPath, Boolean forcePolicyUpdate) {
    this.settingsXmlFilePath = settingsXmlFilePath;
    this.globalSettingsXmlFilePath = globalSettingsXmlFilePath;
    this.mavenRepositoryDirectoryPath = mavenRepositoryDirectoryPath;
    this.forcePolicyUpdate = forcePolicyUpdate;
  }

  public String getSettingsXmlFilePath() {
    return settingsXmlFilePath;
  }

  public String getGlobalSettingsXmlFilePath() {
    return globalSettingsXmlFilePath;
  }

  public String getMavenRepositoryDirectoryPath() {
    return mavenRepositoryDirectoryPath;
  }

  public Boolean getForcePolicyUpdate() {
    return forcePolicyUpdate;
  }

  /**
   * Maven Configuration Builder
   *
   * @author Mulesoft Inc.
   * @since 2.0.0
   */
  public static class MavenConfigurationBuilder {

    private String settingsXmlFilePath;
    private String globalSettingsXmlFilePath;
    private String mavenRepositoryDirectoryPath;
    private Boolean forcePolicyUpdate;

    public MavenConfigurationBuilder withSettingsXmlFilePath(String settingsXmlFilePath) {
      this.settingsXmlFilePath = settingsXmlFilePath;
      return this;
    }

    public MavenConfigurationBuilder withGlobalSettingsXmlFilePath(String globalSettingsXmlFilePath) {
      this.globalSettingsXmlFilePath = globalSettingsXmlFilePath;
      return this;
    }

    public MavenConfigurationBuilder withMavenRepositoryDirectoryPath(String mavenRepositoryDirectoryPath) {
      this.mavenRepositoryDirectoryPath = mavenRepositoryDirectoryPath;
      return this;
    }

    public MavenConfigurationBuilder withForcePolicyUpdate(Boolean forcePolicyUpdate) {
      this.forcePolicyUpdate = forcePolicyUpdate;
      return this;
    }

    public MavenConfiguration build() {
      return new MavenConfiguration(settingsXmlFilePath, globalSettingsXmlFilePath, mavenRepositoryDirectoryPath,
                                    forcePolicyUpdate);
    }
  }
}

==> munit-remote-2.1.0-sources.jar: org/mule/munit/remote/api/configuration/MavenConfiguration.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
/*
* Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
* copyright law. All use of this software is subject to MuleSoft's Master Subscription
* Agreement (or other master license agreement) separately entered into in writing between
* you and MuleSoft. If such an agreement is not in place, you may not use the software.
*/
package org.mule.munit.remote.api.configuration;

/**
 * Define the configuration required for mule-maven-client
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class MavenConfiguration {

  private String settingsXmlFilePath;
  private String globalSettingsXmlFilePath;
  private String mavenRepositoryDirectoryPath;

  private Boolean offlineMode = Boolean.FALSE;
  private Boolean forcePolicyUpdate = Boolean.FALSE;

  protected MavenConfiguration(String settingsXmlFilePath, String globalSettingsXmlFilePath,
                               String mavenRepositoryDirectoryPath, Boolean forcePolicyUpdate, Boolean offlineMode) {
    this.settingsXmlFilePath = settingsXmlFilePath;
    this.globalSettingsXmlFilePath = globalSettingsXmlFilePath;
    this.mavenRepositoryDirectoryPath = mavenRepositoryDirectoryPath;
    this.offlineMode = offlineMode;
    this.forcePolicyUpdate = forcePolicyUpdate;
  }

  public String getSettingsXmlFilePath() {
    return settingsXmlFilePath;
  }

  public String getGlobalSettingsXmlFilePath() {
    return globalSettingsXmlFilePath;
  }

  public String getMavenRepositoryDirectoryPath() {
    return mavenRepositoryDirectoryPath;
  }

  public Boolean getOfflineMode() {
    return offlineMode;
  }

  public Boolean getForcePolicyUpdate() {
    return forcePolicyUpdate;
  }

  /**
   * Maven Configuration Builder
   *
   * @author Mulesoft Inc.
   * @since 2.0.0
   */
  public static class MavenConfigurationBuilder {

    private String settingsXmlFilePath;
    private String globalSettingsXmlFilePath;
    private String mavenRepositoryDirectoryPath;
    private Boolean offlineMode = Boolean.FALSE;
    private Boolean forcePolicyUpdate = Boolean.FALSE;

    public static MavenConfigurationBuilder from(MavenConfiguration mc) {
      MavenConfigurationBuilder builder = new MavenConfigurationBuilder();

      builder.withSettingsXmlFilePath(mc.getSettingsXmlFilePath())
          .withGlobalSettingsXmlFilePath(mc.getGlobalSettingsXmlFilePath())
          .withMavenRepositoryDirectoryPath(mc.getMavenRepositoryDirectoryPath())
          .withForcePolicyUpdate(mc.getForcePolicyUpdate())
          .withOfflineMode(mc.getOfflineMode());

      return builder;
    }

    public MavenConfigurationBuilder withSettingsXmlFilePath(String settingsXmlFilePath) {
      this.settingsXmlFilePath = settingsXmlFilePath;
      return this;
    }

    public MavenConfigurationBuilder withGlobalSettingsXmlFilePath(String globalSettingsXmlFilePath) {
      this.globalSettingsXmlFilePath = globalSettingsXmlFilePath;
      return this;
    }

    public MavenConfigurationBuilder withMavenRepositoryDirectoryPath(String mavenRepositoryDirectoryPath) {
      this.mavenRepositoryDirectoryPath = mavenRepositoryDirectoryPath;
      return this;
    }

    public MavenConfigurationBuilder withForcePolicyUpdate(Boolean forcePolicyUpdate) {
      this.forcePolicyUpdate = forcePolicyUpdate;
      return this;
    }

    public MavenConfigurationBuilder withOfflineMode(Boolean offlineMode) {
      this.offlineMode = offlineMode;
      return this;
    }

    public MavenConfiguration build() {
      return new MavenConfiguration(settingsXmlFilePath, globalSettingsXmlFilePath, mavenRepositoryDirectoryPath,
                                    forcePolicyUpdate, offlineMode);
    }
  }
}
